@@ -1,7 +1,7 @@
 /*
  hstr_utils.c       utilities
 
- Copyright (C) 2014-2022  Martin Dvorak <martin.dvorak@mindforger.com>
+ Copyright (C) 2014-2023 Martin Dvorak <martin.dvorak@mindforger.com>
 
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
@@ -23,10 +23,15 @@
 // TODO PID_BUFFER 20+ characters might be enough
 #define PID_BUFFER_SIZE 128
 
-// This define  is used to compile out code which inserts command to console - thus
-// define allows to activate and debug shell script workaround that is used on WSL
-// and Cygwin.
-//#define DEBUG_NO_TIOCSTI
+/*
+ * global variables
+ */
+
+bool is_tiocsti = false;
+
+/*
+ * functions
+ */
 
 // strdup() not in ISO C
 char* hstr_strdup(const char* s)
@@ -106,13 +111,48 @@ void hstr_chop(char *s)
     }
 }
 
-#if !defined(__MS_WSL__) && !defined(__CYGWIN__) && !defined(DEBUG_NO_TIOCSTI)
-void tiocsti()
+bool is_tiocsti_supported(void)
+{
+#if defined(__MS_WSL__) || defined(__CYGWIN__)
+    return false;
+#else
+   int fd;
+   struct termios t;
+
+   fd = open("/dev/tty", O_RDWR);
+   if (fd < 0) {
+      printf("Error: unable to detect whether TIOCSTI is supported by the kernel");
+      perror("open /dev/tty");
+      return false;
+   }
+   if (tcgetattr(fd, &t) < 0) {
+      printf("Error: unable to detect whether TIOCSTI is supported by the kernel");
+      perror("tcgetattr");
+      return false;
+   }
+
+   bool is_supported = false;
+   // probe TIOCSTI by sending (and clearing) the character
+   if (!ioctl(fd, TIOCSTI, " ")) { // send probe character
+      tcflush(fd, TCIOFLUSH); // flush probe character (avoid insert to prompt)
+      return true;
+   }
+   close(fd);
+
+   return is_supported;
+#endif
+}
+
+#if !defined(__MS_WSL__) && !defined(__CYGWIN__)
+void tiocsti(void)
 {
     char buf[] = DEFAULT_COMMAND;
     unsigned i;
     for (i=0; i<sizeof buf-1; i++) {
-        ioctl(0, TIOCSTI, &buf[i]);
+        if (ioctl(0, TIOCSTI, &buf[i]) < 0) {
+            perror("Unable to execute TIOCSTI using ioctl()");
+            exit(1);
+        }
     }
 }
 #endif
@@ -120,21 +160,21 @@ void tiocsti()
 void fill_terminal_input(char* cmd, bool padding)
 {
     if(cmd && strlen(cmd)>0) {
-#if defined(__MS_WSL__) || defined(__CYGWIN__) || defined(DEBUG_NO_TIOCSTI)
-        fprintf(stderr, "%s", cmd);
-        if(padding) fprintf(stderr, "%s", "\n");
-#else
-        size_t size = strlen(cmd);
-        unsigned i;
-        char *c;
-        for (i = 0; i < size; i++) {
-            // terminal I/O control, simulate terminal input
-            c=(cmd+i);
-            ioctl(0, TIOCSTI, c);
+            if(is_tiocsti) {
+            size_t size = strlen(cmd);
+            unsigned i;
+            char *c;
+            for (i = 0; i < size; i++) {
+                // terminal I/O control, simulate terminal input
+                c=(cmd+i);
+                ioctl(0, TIOCSTI, c);
+            }
+            // echo, but don't flush to terminal
+            if(padding) printf("\n");
+        } else {
+            fprintf(stderr, "%s", cmd);
+            if(padding) fprintf(stderr, "%s", "\n");
         }
-        // echo, but don't flush to terminal
-        if(padding) printf("\n");
-#endif
     }
 }
 
@@ -227,7 +267,7 @@ char *get_shell_name_by_ppid(const int pid)
     return name;
 }
 
-bool isZshParentShell(void) {
+bool is_zsh_parent_shell(void) {
     pid_t parentPid=getppid();
     char* cmdline=get_shell_name_by_ppid(parentPid);
     bool result=cmdline && strstr(cmdline, "zsh");
